# UPathTools

[![PyPI License](https://img.shields.io/pypi/l/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Package status](https://img.shields.io/pypi/status/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Monthly downloads](https://img.shields.io/pypi/dm/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Distribution format](https://img.shields.io/pypi/format/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Wheel availability](https://img.shields.io/pypi/wheel/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Python version](https://img.shields.io/pypi/pyversions/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Implementation](https://img.shields.io/pypi/implementation/upathtools.svg)](https://pypi.org/project/upathtools/)
[![Releases](https://img.shields.io/github/downloads/phil65/upathtools/total.svg)](https://github.com/phil65/upathtools/releases)
[![Github Contributors](https://img.shields.io/github/contributors/phil65/upathtools)](https://github.com/phil65/upathtools/graphs/contributors)
[![Github Discussions](https://img.shields.io/github/discussions/phil65/upathtools)](https://github.com/phil65/upathtools/discussions)
[![Github Forks](https://img.shields.io/github/forks/phil65/upathtools)](https://github.com/phil65/upathtools/forks)
[![Github Issues](https://img.shields.io/github/issues/phil65/upathtools)](https://github.com/phil65/upathtools/issues)
[![Github Issues](https://img.shields.io/github/issues-pr/phil65/upathtools)](https://github.com/phil65/upathtools/pulls)
[![Github Watchers](https://img.shields.io/github/watchers/phil65/upathtools)](https://github.com/phil65/upathtools/watchers)
[![Github Stars](https://img.shields.io/github/stars/phil65/upathtools)](https://github.com/phil65/upathtools/stars)
[![Github Repository size](https://img.shields.io/github/repo-size/phil65/upathtools)](https://github.com/phil65/upathtools)
[![Github last commit](https://img.shields.io/github/last-commit/phil65/upathtools)](https://github.com/phil65/upathtools/commits)
[![Github release date](https://img.shields.io/github/release-date/phil65/upathtools)](https://github.com/phil65/upathtools/releases)
[![Github language count](https://img.shields.io/github/languages/count/phil65/upathtools)](https://github.com/phil65/upathtools)
[![Github commits this month](https://img.shields.io/github/commit-activity/m/phil65/upathtools)](https://github.com/phil65/upathtools)
[![Package status](https://codecov.io/gh/phil65/upathtools/branch/main/graph/badge.svg)](https://codecov.io/gh/phil65/upathtools/)
[![PyUp](https://pyup.io/repos/github/phil65/upathtools/shield.svg)](https://pyup.io/repos/github/phil65/upathtools/)

[Read the documentation!](https://phil65.github.io/upathtools/)
